==> qt-creator-opensource-src-4.2.2.zip: qt-creator-opensource-src-4.2.2/src/tools/clangrefactoringbackend/source/refactoringserver.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef CLANGBACKEND_REFACTORINGSERVER_H
#define CLANGBACKEND_REFACTORINGSERVER_H

#include <refactoringserverinterface.h>

namespace ClangBackEnd {

class RefactoringServer : public RefactoringServerInterface
{
public:
    RefactoringServer();

    void end() override;
    void requestSourceLocationsForRenamingMessage(RequestSourceLocationsForRenamingMessage &&message) override;
};

} // namespace ClangBackEnd

#endif // CLANGBACKEND_REFACTORINGSERVER_H

==> qt-creator-opensource-src-4.3.0.zip: qt-creator-opensource-src-4.3.0/src/tools/clangrefactoringbackend/source/refactoringserver.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <refactoringserverinterface.h>

#include <future>
#include <vector>

namespace ClangBackEnd {

class SourceRangesAndDiagnosticsForQueryMessage;

namespace V2 {
class FileContainer;
}

class RefactoringServer : public RefactoringServerInterface
{
    using Future = std::future<SourceRangesAndDiagnosticsForQueryMessage>;
public:
    RefactoringServer();

    void end() override;
    void requestSourceLocationsForRenamingMessage(RequestSourceLocationsForRenamingMessage &&message) override;
    void requestSourceRangesAndDiagnosticsForQueryMessage(RequestSourceRangesAndDiagnosticsForQueryMessage &&message) override;
    void cancel() override;

    bool isCancelingJobs() const;

    void supersedePollEventLoop(std::function<void()> &&pollEventLoop);

private:
    void gatherSourceRangesAndDiagnosticsForQueryMessage(std::vector<V2::FileContainer> &&sources,
                                                         std::vector<V2::FileContainer> &&unsaved,
                                                         Utils::SmallString &&query);
    std::size_t waitForNewSourceRangesAndDiagnosticsForQueryMessage(std::vector<Future> &futures);

private:
    std::function<void()> pollEventLoop;
    std::atomic_bool cancelWork{false};

};

} // namespace ClangBackEnd
